@@ -191,7 +191,7 @@ void MenuItem::setMetaData(const KPluginMetaData &data)
     d->comment = data.description();
     d->iconName = data.iconName();
     d->systemsettingsCategoryModule = data.value(QStringLiteral("X-KDE-System-Settings-Category-Module"));
-    d->isExternalAppModule = data.value(QStringLiteral("IsExternalApp"), false);
+    d->isExternalAppModule = data.value(QStringLiteral("IsExternalApp"), false) || data.serviceTypes().contains(QStringLiteral("SystemSettingsExternalApp"));
 }
 
 KPluginMetaData MenuItem::metaData()
